#!/bin/bash

bpath1="$( dirname "$0" )"
mypath="$( cd "$bpath1" && pwd )"

fonts_array=( "Arrows.otf" "ConkyWeather.otf" "ConkyWindNESW.otf" "MoonPhases.ttf" )

ca_menu="
				 Configure Conkywx
			  -----------------------
	This menu is only required for the stand alone version
	Enter your option number:
	  1 Install conkywx fonts system wide in /usr/share/fonts/TTF/conkywx
	  2 Install in ./fonts directory in user home directory
	  3 Un-install conkywx font set

	  q to quit
	  followed by [ENTER]: "


confirm_Y () {
	clear
	echo -n "$1"
	read confirm_y
	case $confirm_y in
	YES)	confirmed=Y 						;;
	*)		echo "Operation cancelled"			;;
	esac
}

wxmp_desktop() {

	sed -i 's`^Exec.*`Exec='"${mypath}"'/lib/wxmp.sh \%F`g' ./examples/wxmp.desktop
	sed -i 's`^wxmprun.*`wxmprun='"${mypath}"'/lib/wxmp.sh \%F`g' ./lib/wxmp.bin
	cp ./lib/wxmp.bin ${mypath}/wxmp

	home_local="$HOME/.local/share/applications"
	home_system='/usr/share/applications'
	home_bin='/usr/bin'

	if [[ $1 == 'system' ]]; then
		if [[ -d "$home_system" ]]; then
			sudo cp ./examples/wxmp.desktop "$home_system"
			sudo cp ./lib/wxmp.bin "$home_bin/wxmp"
		fi
	elif [[ $1 == 'remove' ]]; then
		if [[ -e "$home_local/wxmp.desktop" ]]; then
			rm -rf "$home_local/wxmp.desktop"
		elif [[ -e "$home_system/wxmp.desktop" ]]; then
			sudo rm -rf "$home_system/wxmp.desktop" "$home_bin/wxmp"
		fi
	else
		if [[ -d "$home_local" ]]; then
			cp ./lib/wxmp.desktop "$home_local"
		else
			mkdir -p "$home_local"
			cp ./lib/wxmp.desktop "$home_local"
		fi
	fi

}


fonts_local () {
	cd ./fonts
	echo " "
	echo "installing fonts in ./fonts directory..."
	echo " "
	if [[ -d $HOME/.fonts ]]; then
		cp * $HOME/.fonts
	else
		echo "No ./fonts directory found - creating directory"
		mkdir -p $HOME/.fonts
		cp * $HOME/.fonts
	fi
	cd ..
	echo "Updating font cache..."
	fc-cache -vf		# update font cache
	echo "Completed font installation in ./fonts directory..."
	exit 0
}

rm_fonts () {

	if [[ $1 == "Y" ]]; then
		sudo rm -rf /usr/share/fonts/TTF/conkywx/ > /dev/null
		cd ~
		t1="A"	# this validates a font removal
		wf="/usr/share/fonts/TTF/conkywx"
	else
		for c in ${!fonts_array[@]}
		do
			if [[ -s ${fonts_array[$c]} ]]; then
				rm -f ${fonts_array[$c]} > /dev/null
				t1="A"	# this validates a font removal
			else
				echo "${fonts_array[$c]} not found"
			fi
		done
		wf="./fonts"
	fi
	if [[ $t1 == "A" ]]; then
		echo "Updating font cache..."
		fc-cache -vf		# update font cache
		echo "Completed font Un-installation in $wf directory..."
	fi
	exit 0
}

rm_fonts_local () {
	echo " "
	echo "Un-installing fonts ..."
	echo " "
	if [[ -d $HOME/.fonts ]]; then
		cd $HOME/.fonts
		if [[ $( ls | egrep '(Arrows|Weather|Wind|Moon)' ) != "" ]]; then
			echo "conkywx fonts found in ./fonts directory..."
			rm_fonts
		else
			# echo "No conkywx fonts found in ./fonts directory..."
			nf="N"
		fi
	else
		nf="N"
	fi
	if [[ -d /usr/share/fonts/TTF/conkywx ]]; then
		cd /usr/share/fonts/TTF/conkywx
		if [[ $( ls | egrep '(Arrows|Weather|Wind|Moon)' ) != "" ]]; then
			echo "conkywx fonts found in /usr/share/fonts/TTF/conkywx - password required."
			rm_fonts "Y"
		else
			# echo "No conkywx fonts found in system fonts directory..."
			nf="N"
		fi
	else
		# echo "No conkywx fonts found in system fonts directory..."
		nf="N"
	fi
	if [[ $nf == "N" ]]; then
		echo "No conkywx fonts found ..."
		exit 0
	fi


}

fonts_system () {
	cd ./fonts
	echo " "
	echo "installing fonts - user password required..."
	echo " "
	sudo mkdir -p /usr/share/fonts/TTF/conkywx
	sudo cp * /usr/share/fonts/TTF/conkywx
	echo " "
	echo "updating fonts cache..."
	echo " "
	fc-cache -vf		# update font cache
	cd ..
	echo "Completed font installation..."
	exit 0
}

while [[ ! $qtype =~ ^[1,2,3,4,5,6,q]+$ ]];
do
	clear
	echo -n "$ca_menu"
	  read qtype

	case $qtype in
	1)	clear;
		confirm_Y "Install fonts in system - type YES to confirm: "
		if [[ $confirmed == "Y" ]]; then
			fonts_system
			wxmp_desktop 'system'
		fi
		;;
	2)	clear;
		confirm_Y "Install fonts in local ./fonts directory - type YES to confirm: "
		if [[ $confirmed == "Y" ]]; then
			fonts_local
			wxmp_desktop
		fi
		;;
	3)	clear;
		confirm_Y "Un-install / remove conkywx fonts - type YES to confirm: "
		if [[ $confirmed == "Y" ]]; then
			rm_fonts_local
			wxmp_desktop 'remove'
		fi
		;;
	q)	echo "Nothing to do bye bye ;-)"
		exit 0															;;
	esac

done
