 //
 // Consolidated include file for Magellan
 // 08809870865
/*
 *  Handy mathematical functions and constants
 */
#define EPSILON 1E-6
#define abs(x) ((x) < 0 ? (-(x)) : (x))                   /* Absolute val */
#define fixangle(a) ((a) - 360.0 * (floor((a) / 360.0)))  /* Fix angle    */
#define torad(d) ((d) * (PI / 180.0))                     /* Deg->Rad     */
#define todeg(d) ((d) * (180.0 / PI))                     /* Rad->Deg     */
#define dsin(x) (sin(torad((x))))                         /* Sin from deg */
#define dcos(x) (cos(torad((x))))                         /* Cos from deg */

#define twoPI		( 2 * PI )
#define RADEG		( 180.0 / PI )
#define DEGRAD		( PI / 180.0 )

#define sind(x)  sin((x)*DEGRAD)
#define cosd(x)  cos((x)*DEGRAD)
#define tand(x)  tan((x)*DEGRAD)

#define atand(x)    (RADEG*atan(x))
#define asind(x)    (RADEG*asin(x))
#define acosd(x)    (RADEG*acos(x))
#define atan2d(y,x) (RADEG*atan2(y,x))

/*
 *  Astronomical constants
 */
#define epoch       2444238.5      /* 1980 January 0.0 */

/*
 *  Constants defining the Sun's apparent orbit
 */
#define elonge      278.833540     /* Ecliptic longitude of the Sun at epoch 1980.0 */
#define elongp      282.596403     /* Ecliptic longitude of the Sun at perigee */
#define eccent      0.016718       /* Eccentricity of Earth's orbit */
#define sunsmax     1.495985e8     /* Semi-major axis of Earth's orbit, km */
#define sunangsiz   0.533128       /* Sun's angular size, degs, at semi-major axis distance */

/*
 *  Elements of the Moon's orbit, epoch 1980.0
 */
#define mmlong      64.975464      /* Moon's mean lonigitude at the epoch */
#define mmlongp     349.383063     /* Mean longitude of the perigee at the epoch */
#define mlnode      151.950429     /* Mean longitude of the node at the epoch */
#define minc        5.145396       /* Inclination of the Moon's orbit */
#define mecc        0.054900       /* Eccentricity of the Moon's orbit */
#define mangsiz     0.5181         /* Moon's angular size at distance a from Earth */
#define msmax       384401.0       /* Semi-major axis of Moon's orbit in km */
#define mparallax   0.9507         /* Parallax at distance a from Earth */
#define synmonth    29.53058868    /* Synodic month (new Moon to new Moon) */
#define lunatbase   2423436.0      /* Base date for E. W. Brown's numbered series of lunations (1923 January 16) */

/*
 *  Properties of the Earth
 */
#define earthrad    6378.16        /* Radius of Earth in kilometres */

#define FALSE 0
#define TRUE  1

#define PI 3.14159265358979323846

#define TMOD(x) ((x)<0?(x)+24:((x)>=24?(x)-24:(x)))
#define DAYSOFF(x) ((x)<0?"(-1) ":((x)>=24?"(+1) ":""))

#define HOURS(h) ((int)(floor(h)))
#define MINUTES(h) ((int)(60*(h-floor(h))))

#define ABS(x) ((x)<0?-(x):(x))

/* A macro to compute the number of days elapsed since 2000 Jan 0.0 */
/* (which is equal to 1999 Dec 31, 0h UT)                           */
#define days_since_2000_Jan_0(y,m,d) \
	(367L*(y)-((7*((y)+(((m)+9)/12)))/4)+((275*(m))/9)+(d)-730530L)

struct tm mk_tm(int year, int month, int day, int hour, int minute, int second) ;

#define SIZE 100
#define SIZE2 200

char tformat[SIZE], moon_format[SIZE], met_str[SIZE2];
// tformat[0] = "0";
// moon_format[0] = "0";
// char *tformat, *moon_format;
char buffer[SIZE], buffer2[SIZE];

//Magellan functions
double get_julian_date(int year, int month, int day, double UT);
double julianDay(double yy, double mm, double dd, double hh);
float ipart (double x);
double fpart (double x);
double sinalt (int object, double mjd0, double hour, double ourlong, double cphi, double sphi );
double azalt (int object, double mjd0, double hour, double ourlat, double ourlong );
double lmst (double mjd, double ourlong);
double zalmst (double mjd, double ourlong);
double get_transit (int object, double mjd0, int hour, double ourlong, double ourlat);
void get_sun_pos (double t, double *ra, double *dec);
void get_moon_pos (double t, double *ra, double *dec);
void quad (double ym, double y0, double yp, double *xe, double *ye, double *z1,
				double *z2, int *nz);
void display_event_time (double time, char objname [4], char event [6], int year, int month, int day);
// double get_moon_phase (double date);
// double get_underfoot (double date, double underlong);
int get_rst (int object, double date, double ourlong, double ourlat,
				int year, int month, int day,
				double *Rise, double *Set, double *Transit);


//**********************************************************************

/* This macro computes times for sunrise/sunset.                      */
/* Sunrise/set is considered to occur when the Sun's upper limb is    */
/* 35 arc minutes below the horizon (this accounts for the refraction */
/* of the Earth's atmosphere).                                        */
#define sun_rise_set(year,month,day,lon,lat,rise,set)  \
		__sunriset__( year, month, day, lon, lat, -35.0/60.0, 1, rise, set )

/* This macro computes the start and end times of civil twilight.       */
/* Civil twilight starts/ends when the Sun's center is 6 degrees below  */
/* the horizon.                                                         */
#define civil_twilight(year,month,day,lon,lat,start,end)  \
		__sunriset__( year, month, day, lon, lat, -6.0, 0, start, end )

/* This macro computes the start and end times of nautical twilight.    */
/* Nautical twilight starts/ends when the Sun's center is 12 degrees    */
/* below the horizon.                                                   */
#define nautical_twilight(year,month,day,lon,lat,start,end)  \
		__sunriset__( year, month, day, lon, lat, -12.0, 0, start, end )

/* This macro computes the start and end times of astronomical twilight.   */
/* Astronomical twilight starts/ends when the Sun's center is 18 degrees   */
/* below the horizon.                                                      */
#define astronomical_twilight(year,month,day,lon,lat,start,end)  \
		__sunriset__( year, month, day, lon, lat, -18.0, 0, start, end )

int __sunriset__( int year, int month, int day, double lon, double lat,
				  double altit, int upper_limb, double *rise, double *set );

int print_everything(int year, int month, int day,
					double ourlat, double ourlong,
					double tz, char local);

double revolution( double x );

double rev180( double x );

double GMST0( double d );

void sunpos( double d, double *lon, double *r );

void sun_RA_dec( double d, double *RA, double *dec, double *r );

void remove_chars(char* str, char c);

void moonWords(const char *string);

const char* timezone_name;
long int timezone_offset;

